@@ -21,19 +21,19 @@ module Capistrano
         # Returns the command that will check out the given revision to the
         # given destination.
         def checkout(revision, destination)
-          scm :checkout, verbose, authentication, "-r#{revision}", repository, destination
+          scm :checkout, arguments, verbose, authentication, "-r#{revision}", repository, destination
         end
 
         # Returns the command that will do an "svn update" to the given
         # revision, for the working copy at the given destination.
         def sync(revision, destination)
-          scm :update, verbose, authentication, "-r#{revision}", destination
+          scm :update, arguments, verbose, authentication, "-r#{revision}", destination
         end
 
         # Returns the command that will do an "svn export" of the given revision
         # to the given destination.
         def export(revision, destination)
-          scm :export, verbose, authentication, "-r#{revision}", repository, destination
+          scm :export, arguments, verbose, authentication, "-r#{revision}", repository, destination
         end
 
         # Returns the command that will do an "svn diff" for the two revisions.
@@ -68,7 +68,8 @@ module Capistrano
         # from the SCM. Password prompts, connection requests, passphrases,
         # etc. are handled here.
         def handle_data(state, stream, text)
-	        logger.info "[#{stream}] #{text}"
+          host = state[:channel][:host]
+	        logger.info "[#{host} :: #{stream}] #{text}"
           case text
           when /\bpassword.*:/i
             # subversion is prompting for a password
@@ -97,7 +98,7 @@ module Capistrano
             username = variable(:scm_username)
             return "" unless username
             result = "--username #{variable(:scm_username)} "
-            result << "--password #{variable(:scm_password)} " unless variable(:scm_prefer_prompt)
+            result << "--password #{variable(:scm_password)} " unless variable(:scm_auth_cache) || variable(:scm_prefer_prompt)
             result << "--no-auth-cache " unless variable(:scm_auth_cache)
             result
           end
