@@ -37,6 +37,13 @@ class ConfigurationServersTest < Test::Unit::TestCase
     assert_equal %w(web1 web2).sort, @config.find_servers_for_task(task).map { |s| s.host }.sort
   end
 
+  def test_task_with_unknown_role_should_raise_exception
+    task = new_task(:testing, @config, :roles => :bogus)
+    assert_raises(ArgumentError) do
+      @config.find_servers_for_task(task)
+    end
+  end
+
   def test_task_with_hosts_option_should_apply_only_to_those_hosts
     task = new_task(:testing, @config, :hosts => %w(foo bar))
     assert_equal %w(foo bar).sort, @config.find_servers_for_task(task).map { |s| s.host }.sort
@@ -52,7 +59,7 @@ class ConfigurationServersTest < Test::Unit::TestCase
     task = new_task(:testing)
     assert_equal %w(app1 app2 app3 file).sort, @config.find_servers_for_task(task).map { |s| s.host }.sort
   ensure
-    ENV['ROLES'] = nil
+    ENV.delete('ROLES')
   end
 
   def test_task_with_hosts_as_environment_variable_should_apply_only_to_those_hosts
@@ -60,7 +67,31 @@ class ConfigurationServersTest < Test::Unit::TestCase
     task = new_task(:testing)
     assert_equal %w(foo bar).sort, @config.find_servers_for_task(task).map { |s| s.host }.sort
   ensure
-    ENV['HOSTS'] = nil
+    ENV.delete('HOSTS')
+  end
+
+  def test_task_with_hosts_as_environment_variable_should_not_inspect_roles_at_all
+    ENV['HOSTS'] = "foo,bar"
+    task = new_task(:testing, @config, :roles => :bogus)
+    assert_equal %w(foo bar).sort, @config.find_servers_for_task(task).map { |s| s.host }.sort
+  ensure
+    ENV.delete('HOSTS')
+  end
+
+  def test_task_with_onlyhosts_environment_variable_should_apply_only_to_those_hosts
+    ENV['HOSTFILTER'] = "app1,web1"
+    task = new_task(:testing)
+    assert_equal %w(app1 web1).sort, @config.find_servers_for_task(task).map { |s| s.host }.sort
+  ensure
+    ENV.delete('HOSTFILTER')
+  end
+
+  def test_task_with_onlyhosts_environment_variable_should_filter_hosts_option
+    ENV['HOSTFILTER'] = "foo"
+    task = new_task(:testing, @config, :hosts => %w(foo bar))
+    assert_equal %w(foo).sort, @config.find_servers_for_task(task).map { |s| s.host }.sort
+  ensure
+    ENV.delete('HOSTFILTER')
   end
 
   def test_task_with_only_should_apply_only_to_matching_tasks
